@@ -2,12 +2,15 @@
 module Info (
   versionInfo
 , info
+, version
 #ifdef TEST
 , formatInfo
 #endif
 ) where
 
-import           Data.List.Compat
+import           Imports
+
+import           Data.List
 import           System.Process
 import           System.IO.Unsafe
 
@@ -17,14 +20,23 @@ import           Config as GHC
 import           GHC.Settings.Config as GHC
 #endif
 
+import           Interpreter (ghc)
+
+#ifdef TEST
+
+version :: String
+version = "0.0.0"
+
+#else
+
 import           Data.Version (showVersion)
 import qualified Paths_doctest
 
-import           Interpreter (ghc)
-
 version :: String
 version = showVersion Paths_doctest.version
 
+#endif
+
 ghcVersion :: String
 ghcVersion = GHC.cProjectVersion
 
