@@ -1,5 +1,4 @@
 {-# LANGUAGE CPP #-}
-
 module Interpreter (
   Interpreter
 , safeEval
@@ -14,9 +13,10 @@ module Interpreter (
 , filterExpression
 ) where
 
+import           Imports
+
 import           System.Process
 import           System.Directory (getPermissions, executable)
-import           Control.Monad
 import           Control.Exception hiding (handle)
 import           Data.Char
 import           GHC.Paths (ghc)
@@ -37,30 +37,25 @@ interpreterSupported = do
   unless (executable x) $ do
     fail $ ghc ++ " is not executable!"
 
-  maybe False (== "YES") . lookup haveInterpreterKey <$> ghcInfo
+  (== Just "YES") . lookup haveInterpreterKey <$> ghcInfo
 
--- | Run an interpreter session.
---
--- Example:
---
--- >>> withInterpreter [] $ \i -> eval i "23 + 42"
--- ...
--- "65\n"
 withInterpreter
-  :: [String]               -- ^ List of flags, passed to GHC
+  :: (String, [String])
   -> (Interpreter -> IO a)  -- ^ Action to run
   -> IO a                   -- ^ Result of action
-withInterpreter flags action = do
+withInterpreter (command, flags) action = do
   let
     args = flags ++ [
-        "--interactive"
-      , xTemplateHaskell
+        xTemplateHaskell
 #if __GLASGOW_HASKELL__ >= 802
       , "-fdiagnostics-color=never"
       , "-fno-diagnostics-show-caret"
+#endif
+#if __GLASGOW_HASKELL__ >= 810 && __GLASGOW_HASKELL__ < 904
+      , "-Wno-unused-packages"
 #endif
       ]
-  bracket (new defaultConfig{configGhci = ghc} args) close action
+  bracket (new defaultConfig{configGhci = command} args) close action
 
 xTemplateHaskell :: String
 xTemplateHaskell = "-XTemplateHaskell"
