@@ -1,17 +1,26 @@
 {-# LANGUAGE CPP #-}
 module Run (
   doctest
+, doctestWithRepl
+
+, Config(..)
+, defaultConfig
+, doctestWith
+
+, Result
+, Summary(..)
+, isSuccess
+, evaluateResult
+, doctestWithResult
+
+, runDocTests
 #ifdef TEST
-, doctestWithOptions
-, Summary
 , expandDirs
 #endif
 ) where
 
-import           Prelude ()
-import           Prelude.Compat
+import           Imports
 
-import           Control.Monad (when, unless)
 import           System.Directory (doesFileExist, doesDirectoryExist, getDirectoryContents)
 import           System.Environment (getEnvironment)
 import           System.Exit (exitFailure, exitSuccess)
@@ -30,8 +39,10 @@ import           GHC.Utils.Panic
 
 import           PackageDBs
 import           Parse
-import           Options
+import           Options hiding (Result(..))
+import qualified Options
 import           Runner
+import           Location
 import qualified Interpreter
 
 -- | Run doctest with given list of arguments.
@@ -48,10 +59,13 @@ import qualified Interpreter
 -- If a directory is given, it is traversed to find all .hs and .lhs files
 -- inside of it, ignoring hidden entries.
 doctest :: [String] -> IO ()
-doctest args0 = case parseOptions args0 of
-  RunGhc args -> rawSystem Interpreter.ghc args >>= E.throwIO
-  Output s -> putStr s
-  Result (Run warnings args_ magicMode fastMode preserveIt verbose) -> do
+doctest = doctestWithRepl (repl defaultConfig)
+
+doctestWithRepl :: (String, [String]) -> [String] -> IO ()
+doctestWithRepl repl args0 = case parseOptions args0 of
+  Options.ProxyToGhc args -> rawSystem Interpreter.ghc args >>= E.throwIO
+  Options.Output s -> putStr s
+  Options.Result (Run warnings magicMode config) -> do
     mapM_ (hPutStrLn stderr) warnings
     hFlush stderr
 
@@ -60,22 +74,14 @@ doctest args0 = case parseOptions args0 of
       hPutStrLn stderr "WARNING: GHC does not support --interactive, skipping tests"
       exitSuccess
 
-    args <- case magicMode of
-      False -> return args_
+    opts <- case magicMode of
+      False -> return (ghcOptions config)
       True -> do
-        expandedArgs <- concat <$> mapM expandDirs args_
+        expandedArgs <- concat <$> mapM expandDirs (ghcOptions config)
         packageDBArgs <- getPackageDBArgs
         addDistArgs <- getAddDistArgs
         return (addDistArgs $ packageDBArgs ++ expandedArgs)
-
-    r <- doctestWithOptions fastMode preserveIt verbose args `E.catch` \e -> do
-      case fromException e of
-        Just (UsageError err) -> do
-          hPutStrLn stderr ("doctest: " ++ err)
-          hPutStrLn stderr "Try `doctest --help' for more information."
-          exitFailure
-        _ -> E.throwIO e
-    when (not $ isSuccess r) exitFailure
+    doctestWith config{repl, ghcOptions = opts}
 
 -- | Expand a reference to a directory to all .hs and .lhs files within it.
 expandDirs :: String -> IO [String]
@@ -109,10 +115,7 @@ expandDirs fp0 = do
 getAddDistArgs :: IO ([String] -> [String])
 getAddDistArgs = do
     env <- getEnvironment
-    let dist =
-            case lookup "HASKELL_DIST_DIR" env of
-                Nothing -> "dist"
-                Just x -> x
+    let dist = fromMaybe "dist" $ lookup "HASKELL_DIST_DIR" env
         autogen = dist ++ "/build/autogen/"
         cabalMacros = autogen ++ "cabal_macros.h"
 
@@ -128,14 +131,28 @@ getAddDistArgs = do
                     else id) rest
         else return id
 
-isSuccess :: Summary -> Bool
+doctestWith :: Config -> IO ()
+doctestWith = doctestWithResult >=> evaluateResult
+
+type Result = Summary
+
+isSuccess :: Result -> Bool
 isSuccess s = sErrors s == 0 && sFailures s == 0
 
-doctestWithOptions :: Bool -> Bool -> Bool -> [String] -> IO Summary
-doctestWithOptions fastMode preserveIt verbose args = do
+evaluateResult :: Result -> IO ()
+evaluateResult r = unless (isSuccess r) exitFailure
 
-  -- get examples from Haddock comments
-  modules <- getDocTests args
+doctestWithResult :: Config -> IO Result
+doctestWithResult config = do
+  (extractDocTests (ghcOptions config) >>= runDocTests config) `E.catch` \e -> do
+    case fromException e of
+      Just (UsageError err) -> do
+        hPutStrLn stderr ("doctest: " ++ err)
+        hPutStrLn stderr "Try `doctest --help' for more information."
+        exitFailure
+      _ -> E.throwIO e
 
-  Interpreter.withInterpreter args $ \repl -> withCP65001 $ do
-    runModules fastMode preserveIt verbose repl modules
+runDocTests :: Config -> [Module [Located DocTest]] -> IO Result
+runDocTests Config{..} modules = do
+  Interpreter.withInterpreter ((<> ghcOptions) <$> repl) $ \ interpreter -> withCP65001 $ do
+    runModules fastMode preserveIt verbose interpreter modules
