@@ -1,11 +1,11 @@
 module OptionsSpec (spec) where
 
-import           Prelude ()
-import           Prelude.Compat
-import           Data.List.Compat
+import           Imports
+
+import           Data.List
 
 import           Test.Hspec
-import           Test.QuickCheck
+import           Test.QuickCheck hiding (verbose)
 
 import           Options
 
@@ -18,18 +18,25 @@ instance Arbitrary NonInteractive where
 spec :: Spec
 spec = do
   describe "parseOptions" $ do
-    let warning = ["WARNING: --optghc is deprecated, doctest now accepts arbitrary GHC options\ndirectly."]
+    let
+      run :: [String] -> Run
+      run ghcOptions = defaultRun {
+        runWarnings = ["WARNING: --optghc is deprecated, doctest now accepts arbitrary GHC options\ndirectly."]
+      , runMagicMode = True
+      , runConfig = defaultConfig { ghcOptions }
+      }
+
     it "strips --optghc" $
-      parseOptions ["--optghc", "foobar"] `shouldBe` Result (Run warning ["foobar"] defaultMagic defaultFastMode defaultPreserveIt defaultVerbose)
+      parseOptions ["--optghc", "foobar"] `shouldBe` Result (run ["foobar"])
 
     it "strips --optghc=" $
-      parseOptions ["--optghc=foobar"] `shouldBe` Result (Run warning ["foobar"] defaultMagic defaultFastMode defaultPreserveIt defaultVerbose)
+      parseOptions ["--optghc=foobar"] `shouldBe` Result (run ["foobar"])
 
     context "with ghc options that are not valid with --interactive" $ do
-      it "returns RunGhc" $ do
+      it "returns ProxyToGhc" $ do
         property $ \ (NonInteractive x) xs -> do
           let options = x : xs
-          parseOptions options `shouldBe` RunGhc options
+          parseOptions options `shouldBe` ProxyToGhc options
 
     context "with --interactive" $ do
       let options = ["--interactive", "--foo", "--bar"]
@@ -38,7 +45,10 @@ spec = do
         runMagicMode <$> parseOptions options `shouldBe` Result False
 
       it "filters out --interactive" $ do
-        runOptions <$> parseOptions options `shouldBe` Result ["--foo", "--bar"]
+        ghcOptions . runConfig <$> parseOptions options `shouldBe` Result ["--foo", "--bar"]
+
+      it "accepts --fast" $ do
+        fastMode . runConfig <$> parseOptions ("--fast" : options) `shouldBe` Result True
 
     describe "--no-magic" $ do
       context "without --no-magic" $ do
@@ -52,20 +62,20 @@ spec = do
     describe "--fast" $ do
       context "without --fast" $ do
         it "disables fast mode" $ do
-          runFastMode <$> parseOptions [] `shouldBe` Result False
+          fastMode . runConfig <$> parseOptions [] `shouldBe` Result False
 
       context "with --fast" $ do
         it "enabled fast mode" $ do
-          runFastMode <$> parseOptions ["--fast"] `shouldBe` Result True
+          fastMode . runConfig <$> parseOptions ["--fast"] `shouldBe` Result True
 
     describe "--preserve-it" $ do
       context "without --preserve-it" $ do
         it "does not preserve the `it` variable" $ do
-          runPreserveIt <$> parseOptions [] `shouldBe` Result False
+          preserveIt . runConfig <$> parseOptions [] `shouldBe` Result False
 
       context "with --preserve-it" $ do
         it "preserves the `it` variable" $ do
-          runPreserveIt <$> parseOptions ["--preserve-it"] `shouldBe` Result True
+          preserveIt . runConfig <$> parseOptions ["--preserve-it"] `shouldBe` Result True
 
     context "with --help" $ do
       it "outputs usage information" $ do
@@ -82,8 +92,8 @@ spec = do
     describe "--verbose" $ do
       context "without --verbose" $ do
         it "is not verbose by default" $ do
-          runVerbose <$> parseOptions [] `shouldBe` Result False
+          verbose . runConfig <$> parseOptions [] `shouldBe` Result False
 
       context "with --verbose" $ do
         it "parses verbose option" $ do
-          runVerbose <$> parseOptions ["--verbose"] `shouldBe` Result True
+          verbose . runConfig <$> parseOptions ["--verbose"] `shouldBe` Result True
