@@ -1,12 +1,11 @@
 module PackageDBsSpec (main, spec) where
 
-import           Prelude ()
-import           Prelude.Compat
+import           Imports
 
 import qualified Control.Exception         as E
 import           Data.List                 (intercalate)
 import           PackageDBs
-import           System.Environment.Compat
+import           System.Environment
 import           System.FilePath           (searchPathSeparator)
 import           Test.Hspec
 
