@@ -1,8 +1,7 @@
 {-# LANGUAGE CPP #-}
 module RunSpec (main, spec) where
 
-import           Prelude ()
-import           Prelude.Compat
+import           Imports
 
 import           Test.Hspec
 import           System.Exit
@@ -10,7 +9,7 @@ import           System.Exit
 import qualified Control.Exception as E
 import           System.FilePath
 import           System.Directory (getCurrentDirectory, setCurrentDirectory)
-import           Data.List.Compat (isPrefixOf, sort)
+import           Data.List (isPrefixOf, sort)
 import           Data.Char
 
 import           System.IO.Silently
@@ -19,9 +18,6 @@ import qualified Options
 
 import           Run
 
-doctestWithDefaultOptions :: [String] -> IO Summary
-doctestWithDefaultOptions = doctestWithOptions Options.defaultFastMode Options.defaultPreserveIt Options.defaultVerbose
-
 withCurrentDirectory :: FilePath -> IO a -> IO a
 withCurrentDirectory workingDir action = do
   E.bracket getCurrentDirectory setCurrentDirectory $ \_ -> do
@@ -119,16 +115,31 @@ spec = do
       hSilence [stderr] $ doctest ["-fdiagnostics-color=always", "test/integration/color/Foo.hs"]
 #endif
 
-  describe "doctestWithOptions" $ do
+  describe "doctestWithResult" $ do
     context "on parse error" $ do
-      let action = withCurrentDirectory "test/integration/parse-error" (doctestWithDefaultOptions ["Foo.hs"])
+      let
+        action = withCurrentDirectory "test/integration/parse-error" $ do
+          doctestWithResult defaultConfig { ghcOptions = ["Foo.hs"] }
 
       it "aborts with (ExitFailure 1)" $ do
         hSilence [stderr] action `shouldThrow` (== ExitFailure 1)
 
       it "prints a useful error message" $ do
         (r, _) <- hCapture [stderr] (E.try action :: IO (Either ExitCode Summary))
-        stripAnsiColors (removeLoadedPackageEnvironment r) `shouldBe` "\nFoo.hs:6:1: error:\n    parse error (possibly incorrect indentation or mismatched brackets)\n"
+        stripAnsiColors (removeLoadedPackageEnvironment r) `shouldBe` unlines (
+#if __GLASGOW_HASKELL__ < 910
+          "" :
+#endif
+#if __GLASGOW_HASKELL__ >= 906
+          [ "Foo.hs:6:1: error: [GHC-58481]"
+#else
+          [ "Foo.hs:6:1: error:"
+#endif
+          , "    parse error (possibly incorrect indentation or mismatched brackets)"
+#if __GLASGOW_HASKELL__ >= 910
+          , ""
+#endif
+          ])
 
   describe "expandDirs" $ do
     it "expands a directory" $ do
