@@ -1,8 +1,7 @@
 {-# LANGUAGE OverloadedStrings #-}
 module Runner.ExampleSpec (main, spec) where
 
-import           Prelude ()
-import           Prelude.Compat
+import           Imports
 
 import           Data.String
 import           Test.Hspec
